@@ -52,7 +52,8 @@ except:
 try:
   from socketserver import ThreadingMixIn
 except:
-  from SocketServer import ThreadingMixIn
+  from SocketServer import ThreadingMixInqZBMfAaH
+  
 
 
 context_types={
@@ -385,12 +386,12 @@ def process_web_request(i):
     r=solution.run({'uid':data_id})
 
     # start program
-#    r=ck.access({'action':'run',
-#          'module_uoa':'program',
-#          'data_uoa':ii.get('program_name',''), 
-#          'cmd_key': 'use_continuous',
-#          'deps.python': 'a699c0c7de43a121',
-#          'quiet': 'yes'})
+    #    r=ck.access({'action':'run',
+    #          'module_uoa':'program',
+    #          'data_uoa':ii.get('program_name',''), 
+    #          'cmd_key': 'use_continuous',
+    #          'deps.python': 'a699c0c7de43a121',
+    #          'quiet': 'yes'})
 
     if r['return']>0: 
       # Process error properly
@@ -419,6 +420,22 @@ def process_web_request(i):
     web_out({'http':http, 'type':'json', 'bin':s.encode('utf8')})
     return
   
+  elif act=='publish_result':
+
+    data_id=ii.get('data_id','')
+
+    r=solution.publish_result({'uid':data_id})
+
+    if r['return']>0: 
+      # Process error properly
+      web_err({'http':http, 'type':xt, 'bin':r['error'].encode('utf8')})
+      return
+
+    solution = {'status': True}
+    s=json.dumps(solution, indent=4, sort_keys=True)
+    web_out({'http':http, 'type':'json', 'bin':s.encode('utf8')})
+    return
+  
   #############################################################################################################3
   elif act=='get_program_result_image':
 
@@ -452,18 +469,18 @@ def process_web_request(i):
     if workflow_output_dir!='':
       cur_dir=os.path.join(cur_dir, workflow_output_dir)
 
-#       r=ck.access({'action':'find',
-#            'module_uoa':'program',
-#            'data_uoa':ii.get('program_name','')})
-#
-#       if r['return']>0: 
-#          # Process error properly
-#          web_err({'http':http, 'type':xt, 'bin':r['error'].encode('utf8')})
-#          return
+    #       r=ck.access({'action':'find',
+    #            'module_uoa':'program',
+    #            'data_uoa':ii.get('program_name','')})
+    #
+    #       if r['return']>0: 
+    #          # Process error properly
+    #          web_err({'http':http, 'type':xt, 'bin':r['error'].encode('utf8')})
+    #          return
 
-#    cur_dir = 'D:\\Work1\\CK\\ck-repos\\local\\cr-solution\\demo-obj-detection-kitti-min-tf-cpu-win\\CK\\ck-tensorflow\\program\\squeezedet\\tmp\\out' #os.path.join(r['path'],"tmp/out") 
-#    cur_dir='/home/cindex/CK/local/cr-solution/demo-obj-detection-self-driving-win/CK/ck-tensorflow/program/squeezedet/tmp/out'
-#    cur_dir='/home/cindex/CK/local/cr-solution/demo-obj-detection-kitti-min-tf-cpu-win/CK/ck-tensorflow/program/squeezedet/tmp/out'
+    #    cur_dir = 'D:\\Work1\\CK\\ck-repos\\local\\cr-solution\\demo-obj-detection-kitti-min-tf-cpu-win\\CK\\ck-tensorflow\\program\\squeezedet\\tmp\\out' #os.path.join(r['path'],"tmp/out") 
+    #    cur_dir='/home/cindex/CK/local/cr-solution/demo-obj-detection-self-driving-win/CK/ck-tensorflow/program/squeezedet/tmp/out'
+    #    cur_dir='/home/cindex/CK/local/cr-solution/demo-obj-detection-kitti-min-tf-cpu-win/CK/ck-tensorflow/program/squeezedet/tmp/out'
 
     # find the penultimate image provided
     try:
@@ -473,6 +490,11 @@ def process_web_request(i):
 
       found_files=[]
 
+      ck.out('')
+      ck.out('Checking for output files in directory:')
+      ck.out('  '+cur_dir)
+      ck.out('')
+
       sorted_list=sorted(os.listdir(cur_dir))
       for file in sorted_list:
         if file.endswith(".png") and file.startswith("boxed_"):
@@ -817,9 +839,7 @@ def process_web_request(i):
     rx=ck.load_json_file({'json_file':pout})
     if rx['return']>0: return rx
 
-    ck.out(json.dumps(rx, indent=2))
-
-    rx=ck.flatten_dict({'dict':rx})
+    rx=ck.flatten_dict(rx)
     if rx['return']>0: return rx
 
     rdf=rx['dict']
@@ -876,7 +896,6 @@ def process_web_request(i):
 
     return
 
-
   #############################################################################################################3
   elif act=='heartbit':
 
